AuthResponse class

Constructors

AuthResponse.error(String code, String message, int statusCode)
factory
AuthResponse.success(Map<String, dynamic> data)
factory

Properties

data Map<String, dynamic>?
final
errorCode String?
final
errorMessage String?
final
hashCode int
The hash code for this object.
no setterinherited
ok bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
statusCode int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited